@@ -200,7 +200,10 @@ class ylog:
         if not self.__enable_lineno:
             return ''
         frame = sys._getframe(2)
-        if frame.f_code.co_filename == os.path.realpath(__file__):
+        if is_windows():
+            if frame.f_code.co_filename.lower() == os.path.realpath(__file__).lower():
+                frame = frame.f_back
+        elif frame.f_code.co_filename == os.path.realpath(__file__):
             frame = frame.f_back
         return f' {color("<<")} {os.path.realpath(frame.f_code.co_filename)}-{frame.f_lineno}'
 
@@ -270,8 +273,8 @@ def get_logger(
     logger.setLevel(level=level)
     if filename:
         if not fmt:
-            fmt = '{name} {levelname: <6}{asctime: <8}: {message}'
-        handler = logging.FileHandler(filename=filename)
+            fmt = '{levelname: <6}{asctime: <8}: {message} {name}'
+        handler = logging.FileHandler(filename=filename, encoding='utf-8')
         formatter = NoColorFormatter(
             fmt=fmt, datefmt=datefmt, style=style)
     else:
